Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(325)

Unified Diff: net/log/net_log_event_type_list.h

Issue 2699433003: Add net-log entries when HttpStream jobs are forced to wait, and when they're delayed and resumed. (Closed)
Patch Set: fix comments from eroman Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/log/net_log_event_type_list.h
diff --git a/net/log/net_log_event_type_list.h b/net/log/net_log_event_type_list.h
index 893f16e08b8bc666e0a351b31a546b90b16bbde8..146b86010bcba4f14eff6e1fe13755a7b7218193 100644
--- a/net/log/net_log_event_type_list.h
+++ b/net/log/net_log_event_type_list.h
@@ -1055,6 +1055,14 @@ EVENT_TYPE(HTTP_STREAM_REQUEST)
// }
EVENT_TYPE(HTTP_STREAM_JOB)
+// Measures the time and HttpStreamFactoryImpl::Job spends waiting for
+// another job.
+// The event parameters are:
+// {
+// "should_wait": <True if the job needs to wait>,
+// }
+EVENT_TYPE(HTTP_STREAM_JOB_WAITING)
+
// Identifies the NetLogSource() for a Job started by the Request.
// The event parameters are:
// {
@@ -1095,12 +1103,18 @@ EVENT_TYPE(HTTP_STREAM_REQUEST_PROTO)
// Job. The orphaned Job will continue to run to completion.
EVENT_TYPE(HTTP_STREAM_JOB_ORPHANED)
-// Emitted when a job is asked to resume after non-zero microseconds.
+// Emitted when a job is delayed.
// {
// "resume_after_ms": <Number of milliseconds until job will be unblocked>
// }
EVENT_TYPE(HTTP_STREAM_JOB_DELAYED)
+// Emitted when a job is asked to resume after non-zero microseconds.
+// {
+// "delay_ms": <Number of milliseconds the job was delayed before resuming>
+// }
+EVENT_TYPE(HTTP_STREAM_JOB_RESUMED)
+
// Marks the start/end of a HttpStreamFactoryImpl::JobController.
// The following parameters are attached:
// {
@@ -1095,12 +1103,18 @@ EVENT_TYPE(HTTP_STREAM_REQUEST_PROTO)
// {
-// "resume_after_ms": <Number of milliseconds until job will be unblocked>
+// "delay_ms": <Number of milliseconds until job will be resumed>
// }
EVENT_TYPE(HTTP_STREAM_JOB_DELAYED)

Powered by Google App Engine
This is Rietveld 408576698